#
# spec file for package xorg-docs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xorg-docs
Version:        1.7.3
Release:        1.2
Summary:        Miscellaneous documentation for the X Window System
License:        MIT
Group:          Documentation/Other
URL:            http://xorg.freedesktop.org/
Source:         %{name}-%{version}.tar.xz
Patch0:         reproducable_build.patch
# For xmlto txt support
BuildRequires:  autoconf >= 2.60
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  xorg-sgml-doctools >= 1.11
# Can be used if we want ps/pdf output
#BuildRequires:  xmlgraphics-fop
BuildRequires:  xmlto >= 0.0.20
BuildRequires:  pkgconfig(xorg-macros) >= 1.10
# Package was named xorg-x11-doc until 12.2
# We use 7.7 for Provides/Obsoletes, since we're renaming the packages when
# X11R7.7 is in RC1, and xorg-x11-doc was version 7.6
Provides:       xorg-x11-doc = 7.7
Obsoletes:      xorg-x11-doc < 7.7
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
This package provides miscellaneous documentation for the X Window
System that doesn't better fit into other packages.

%prep
%autosetup -p1

%build
autoreconf -fi
%configure
make %{?_smp_mflags}

%install
%make_install

%files
%defattr(-,root,root)
%doc %{_datadir}/doc/xorg-docs/
%{_mandir}/man7/Consortium.7%{?ext_man}
%{_mandir}/man7/Standards.7%{?ext_man}
%{_mandir}/man7/X.7%{?ext_man}
%{_mandir}/man7/XOrgFoundation.7%{?ext_man}
%{_mandir}/man7/XProjectTeam.7%{?ext_man}
%{_mandir}/man7/Xsecurity.7%{?ext_man}

%changelog
* Mon Mar 25 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1..7.3
  * Build xz tarballs instead of bzip2
  * gitlab CI: add a basic build test
  * Switch to XORG_DEFAULT_NOCODE_OPTIONS
  * Remove "All rights reserved" from Oracle copyright notices
  * MAINTAINERS: update format
  * MAINTAINERS: update data
  * gitlab CI: Update to latest CI templates & Debian stable release
  * MAINTAINERS: take Xnest maintainership
  * MAINTAINERS: add xisxwayland
  * add maintainer for Xft
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Mon Apr  4 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.7.2
  * X.man: give pointers to specs & other docs
  * X.man: update program lists/info for modern era
  * X.man: document protocol/ syntax in display string
  * X.man: move XLOCAL documentation from Xorg(1) man page
  * Update Solaris URL in MAINTAINERS file
  * Update Solaris info in MAINTAINERS file
  * Add conf.d to fontconfig configuration files list
  * Update README for gitlab migration
  * Update docs for gitlab migration
  * Update configure.ac for gitlab migration
  * Update MAINTAINERS for gitlab migration
  * Mass http -> https replacement where appropriate
  * Update README.xml & XOrgFoundation.man to reflect SPI merger
  * The Katamari is dead!  Long live the Katamari!
  * MAINTAINERS: disclaim maintenance of xdm
  * Drop LBX algortihm specs
  * platforms/Solaris: Drop obsolete notes on apeture drivers
  * Update Versions doc to better reflect current releases
  * Fix spelling/wording issues
  * registry: address updates for Oracle contacts
  * autogen.sh: use quoted string variables
  * remove bogus \/ escapes
  * Update AppleWM and XQuartz maintainers
  * autogen: add default patch prefix
  * autogen.sh: use exec instead of waiting for configure to finish
  * assign libxt maintainer
  * fix typo
  * assign maintainer for Xaw, twm
* Thu Sep 27 2018 sndirsch@suse.com
- reproducable_build.patch (boo#1110020)
* Fri Aug 11 2017 pgajdos@suse.com
- do not require lynx for build, it seems like it is not needed
  at all [bsc#1052980]
* Mon May  4 2015 sndirsch@suse.com
- Update to version 1.7
  * This release provides various minor updates & corrections that have
    accumulated since the last katamari, without waiting forever for
    someone to step up to create the next katamari.
* Sun Jun 10 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.7 / 7.7
* Thu Apr 19 2012 vuntz@opensuse.org
- Rename source and binary package from xorg-x11-doc to
  xorg-docs (upstream name).
- Add Provides/Obsoletes for xorg-x11-doc to smooth upgrades.
- Remove docbook-utils BuildRequires: it's not needed.
* Wed Oct 19 2011 idonmez@suse.com
- Add xmlto dependency to fix bnc#698117
- Cleanup spec file
* Thu May 19 2011 eich@suse.de
- Removed patch: excluded man pages to X and Xsecurity (which
  are shipped with the server package) explicitely in the spec
  file.
* Tue Dec 21 2010 sndirsch@novell.com
- bumped version number to 7.6
* Sun Dec 19 2010 sndirsch@novell.com
- xorg-docs 1.6
  * This release continues the work to convert documents to
    DocBook/XML, to move documents to the modules they more
    logically belong in, to clean up the documents already
    converted to DocBook/XML and to finalize the Release Notes
  for the X11R7.6 katamari.
* Fri Nov 12 2010 sndirsch@novell.com
- xorg-docs 1.5.99.901 (1.6 RC1)
  * This package provides the X Window System documentation that
    doesn't belong in a more specific package. It used to provide
    a lot of docs that did belong in more specific packages, but
    that has largely been corrected in this release:
    git diff --shortstat xorg-docs-1.5..xorg-docs-1.5.99.901
    155 files changed, 27570 insertions(+), 112431 deletions(-)
    The protocol specifications have mostly moved to the matching
    proto modules. The library API references  have mostly moved
    to the matching lib modules. The server internals docs have
    mostly moved to the xorg-server module.
    What's left has mostly (but not yet completely) been converted
    to Docbook XML, from troff, SGML, and other formats.
- adjusted xorg-x11-doc.diff
* Wed Apr  7 2010 sndirsch@suse.de
- unfuzzed 'xorg-x11-doc.diff'
* Sun Apr  4 2010 sndirsch@suse.de
- xorg-docs 1.5
- bumped version number to 7.5
* Thu Sep 11 2008 sndirsch@suse.de
- bumped release number to 7.4
* Tue Oct 23 2007 sndirsch@suse.de
- enabled build of HTML/PDF docs (Bug #335450)
* Sat Sep 29 2007 sndirsch@suse.de
- bumped version to 7.3
* Tue Jul  3 2007 sndirsch@suse.de
- move X(7) and security(7) manual pages to xorg-x11-server package
* Sun Mar  4 2007 sndirsch@suse.de
- updated xorg-docs to release 1.4
  * Major re-organization of the sgml docs. They are now converted
    from linuxdoc to docbook and rely on the docbook2x series of
    tools, so your build environments need to be updated.
- updated xorg-sgml-doctools to release 1.2
  * Update definitions for the 7.2 katamari release
* Wed Nov  8 2006 sndirsch@suse.de
- updated xorg-docs to release 1.3
  * several updates contributed by Alan Coopersmith, David Nusinow,
    Eamon Walsh, Juliusz Chroboczek
- updated xorg-sgml-doctools to release 1.1.1
  * Install defs to the more standard ${prefix}/share/sgml/X11
    which will allow the docbook tools to find them under normal
    conditions
* Thu Oct 26 2006 sndirsch@suse.de
- set version to 7.2 in specfile
* Fri Jul 28 2006 sndirsch@suse.de
- use "-fno-strict-aliasing"
* Thu Jul 27 2006 sndirsch@suse.de
- use $RPM_OPT_FLAGS
* Mon Jun 26 2006 sndirsch@suse.de
- created package
